@@ -3,7 +3,8 @@
 Conntrack::Conntrack(ostream &stdMsg)
 :
     d_options(Options::instance()),
-    d_stdMsg(stdMsg)
+    d_stdMsg(stdMsg),
+    d_accept(d_options.protocols())
 {
     if (access("/proc/net/ip_conntrack", R_OK) != 0)
         throw Exception() << "Cannot read /proc/net/ip_conntrack";
