@@ -15,7 +15,7 @@ class Devices
 
     public:
         Devices(std::ostream &stdMsg);
-        void run(std::ostream &parent);
+        void run();
 };
         
 #endif
