@@ -1,12 +1,10 @@
 #include "devices.ih"
 
-void Devices::run(ostream &parent)
+void Devices::run()
 {
     PcapFilter in(d_options[0], d_record, PcapRecord::IN);
     PcapFilter out(d_options[1], d_record, PcapRecord::OUT);
 
-    parent << 0 << endl;                    // all OK
-
     Signal::instance().add(SIGTERM, in);
     Signal::instance().add(SIGTERM, out);
 
