@@ -9,10 +9,6 @@ Options::Options()
 {
     openConfig();
 
-    if (d_arg.option(0, "conntrack-path"))
-        throw Exception() << "Option 'conntrack-path' discontinued. "
-                    "Use 'conntrack-command' instead";
-
     if (not d_arg.option(&d_conntrackCommand, "conntrack-command"))
         d_conntrackCommand = s_defaultConntrackCommand + setProtocol() +
                              s_defaultConntrackArgs;
