@@ -6,15 +6,21 @@ string Options::setProtocol()
 
     string spec;
     if (not d_arg.option(&spec, "protocol"))
+    {
         ret = " -p tcp";
+        d_conntrackProtocol = "tcp";
+    }
     else if (spec == "all")
-        ret = " -p tcp -p udp -p icmp";
+        d_conntrackProtocol = "tcp udp icmp";
     else
     {
         ret = protocol("icmp", spec);
         ret += protocol("tcp", spec);
         ret += protocol("udp", spec);
 
+        if (d_conntrackProtocol.length() > 4)
+            ret.erase();
+
         if (not spec.empty())
             wmsg << "Protocol specification `" << spec << "' not supported" <<
                                                                     endl;
@@ -22,3 +28,9 @@ string Options::setProtocol()
     return ret;
 }
 
+
+
+
+
+
+
